package Microsoft::AdCenter::V7::ReportingService::RichAdComponentPerformanceReportColumn;
# Copyright (C) 2011 Xerxes Tsang
# This program is free software; you can redistribute it and/or modify it
# under the terms of Perl Artistic License.

use strict;
use warnings;

=head1 NAME

Microsoft::AdCenter::V7::ReportingService::RichAdComponentPerformanceReportColumn - Represents "RichAdComponentPerformanceReportColumn" in Microsoft AdCenter Reporting Service.

=head1 SYNOPSIS

See L<http://msdn.microsoft.com/en-us/library/ee730327.aspx> for documentation of the various data objects.

=head1 ENUMERATION VALUES

AccountName
AccountNumber
AdGroupId
AdGroupName
AdId
AdTitle
CampaignName
ComponentClicks
ComponentCTR
ComponentDestinationURL
ComponentNonBillableClicks
ComponentPosition
ComponentTitle
ComponentTotalClicks
ComponentType
RichAdSubType
TimePeriod

=cut

sub AccountName {
    return 'AccountName';
}

sub AccountNumber {
    return 'AccountNumber';
}

sub AdGroupId {
    return 'AdGroupId';
}

sub AdGroupName {
    return 'AdGroupName';
}

sub AdId {
    return 'AdId';
}

sub AdTitle {
    return 'AdTitle';
}

sub CampaignName {
    return 'CampaignName';
}

sub ComponentClicks {
    return 'ComponentClicks';
}

sub ComponentCTR {
    return 'ComponentCTR';
}

sub ComponentDestinationURL {
    return 'ComponentDestinationURL';
}

sub ComponentNonBillableClicks {
    return 'ComponentNonBillableClicks';
}

sub ComponentPosition {
    return 'ComponentPosition';
}

sub ComponentTitle {
    return 'ComponentTitle';
}

sub ComponentTotalClicks {
    return 'ComponentTotalClicks';
}

sub ComponentType {
    return 'ComponentType';
}

sub RichAdSubType {
    return 'RichAdSubType';
}

sub TimePeriod {
    return 'TimePeriod';
}

1;
